import request from '@/utils/request'

// 查询工资条基础列表
export function listSalaryslip(query) {
  return request({
    url: '/salary/salaryslip/list',
    method: 'get',
    params: query
  })
}

// 查询工资条基础列表
export function excelList(query) {
  return request({
    url: '/salary/salaryslip/excelList',
    method: 'get',
    params: query
  })
}

// 查询工资条基础详细
export function getSalaryslips(id) {
  return request({
    url: '/salary/salaryslip/s/' + id,
    method: 'get'
  })
}

// 查询工资条基础详细
export function getSalaryslip(id) {
  return request({
    url: '/salary/salaryslip/' + id,
    method: 'get'
  })
}

// 新增工资条基础
export function addSalaryslip(data) {
  return request({
    url: '/salary/salaryslip',
    method: 'post',
    data: data
  })
}

// 修改工资条基础
export function updateSalaryslip(data) {
  return request({
    url: '/salary/salaryslip',
    method: 'put',
    data: data
  })
}

// 删除工资条基础
export function delSalaryslip(id) {
  return request({
    url: '/salary/salaryslip/' + id,
    method: 'delete'
  })
}

// 删除工资条基础
export function push(id) {
  return request({
    url: '/salary/salaryslip/push',
    method: 'post',
    data: id
  })
}

// 导出工资条基础
export function exportSalaryslip(query) {
  return request({
    url: '/salary/salaryslip/export',
    method: 'get',
    params: query
  })
}

// 导出工资条基础
export function importTempSalaryslip() {
  return request({
    url: '/salary/salaryslip/importTemp',
    method: 'get'
  })
}
